@@ -2,9 +2,12 @@
 """
 A tool for replicating data from one CDF tenant to another.
 
-To run, configure the source and destination CogniteClient with project and api_key.
-API keys can be set as environment variables COGNITE_SOURCE_API_KEY and
-COGNITE_DESTINATION_API_KEY or through command line arguments.
+To run, configure the source and destination CogniteClient with project and OIDC authentication.
+Client secrets can be set as environment variables:
+```bash
+$ export SOURCE_CLIENT_SECRET=<your source client secret>
+$ export DEST_CLIENT_SECRET=<your destination client secret>
+```
 
 You must provide a config file, give the path either in environment variable
 COGNITE_CONFIG_FILE or as command line argument.
@@ -37,7 +40,9 @@ import cognite.replicator.files
 import cognite.replicator.raw
 import cognite.replicator.replication
 import cognite.replicator.sequences
+import cognite.replicator.sequence_rows
 import cognite.replicator.time_series
+import cognite.replicator.relationships
 
 ENV_VAR_FOR_CONFIG_FILE_PATH = "COGNITE_CONFIG_FILE"
 
@@ -52,6 +57,8 @@ class Resource(Enum):
     ASSETS = auto()
     EVENTS = auto()
     RAW = auto()
+    SEQUENCES = auto()
+    RELATIONSHIPS = auto()
     TIMESERIES = auto()
     DATAPOINTS = auto()
     FILES = auto()
@@ -115,20 +122,19 @@ def _validate_capabilities_oidc(
         check_for_capabilities.append("timeSeriesAcl")
     if "sequences" in needed_capabilities:
         check_for_capabilities.append("sequencesAcl")
+    if "relationships" in needed_capabilities:
+        check_for_capabilities.append("relationshipsAcl")
     if "files" in needed_capabilities:
         check_for_capabilities.append("filesAcl")
     if "raw" in needed_capabilities:
         check_for_capabilities.append("rawAcl")
+    if "datasets" in needed_capabilities:
+        check_for_capabilities.append("datasetsAcl")
 
-    # TODO: add, so that these resources can be replicated as well
-    # if 'relationships' in needed_capabilities:
-    #    check_for_capabilities.append('relationshipsAcl')
     # if 'labels' in needed_capabilities:
     #    check_for_capabilities.append('labelsAcl')
     # if 'types' in needed_capabilities:
     #    check_for_capabilities.append('typesAcl')
-    # if 'datasets' in needed_capabilities:
-    #    check_for_capabilities.append('datasetsAcl')
 
     try:
         if src_api_authentication:
@@ -191,8 +197,6 @@ def get_lines_in_file(config_file):
 
         line_counter += 1
 
-    print(len(lines))
-
     return lines
 
 
@@ -398,10 +402,10 @@ def main():
     if Resource.ASSETS in resources_to_replicate:
         print("Replicating assets...")
         cognite.replicator.assets.replicate(
-            src_client,
-            dst_client,
-            src_dst_dataset_mapping,
-            config,
+            client_src=src_client,
+            client_dst=dst_client,
+            config=config,
+            src_dst_datasets_mapping=src_dst_dataset_mapping,
             delete_replicated_if_not_in_src=delete_replicated_if_not_in_src,
             delete_not_replicated_in_dst=delete_not_replicated_in_dst,
         )
@@ -409,12 +413,12 @@ def main():
     if Resource.EVENTS in resources_to_replicate:
         print("Replicating events...")
         cognite.replicator.events.replicate(
-            src_client,
-            dst_client,
-            src_dst_dataset_mapping,
-            config,
-            config.get("batch_size"),
-            config.get("number_of_threads"),
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+            num_threads=config.get("number_of_threads"),
+            config=config,
+            src_dst_dataset_mapping=src_dst_dataset_mapping,
             delete_replicated_if_not_in_src=delete_replicated_if_not_in_src,
             delete_not_replicated_in_dst=delete_not_replicated_in_dst,
             target_external_ids=config.get("events_external_ids"),
@@ -424,12 +428,12 @@ def main():
     if Resource.TIMESERIES in resources_to_replicate:
         print("Replicating time series...")
         cognite.replicator.time_series.replicate(
-            src_client,
-            dst_client,
-            src_dst_dataset_mapping,
-            config,
-            config.get("batch_size"),
-            config.get("number_of_threads"),
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+            num_threads=config.get("number_of_threads"),
+            config=config,
+            src_dst_dataset_mapping=src_dst_dataset_mapping,
             delete_replicated_if_not_in_src=delete_replicated_if_not_in_src,
             delete_not_replicated_in_dst=delete_not_replicated_in_dst,
             target_external_ids=config.get("timeseries_external_ids"),
@@ -440,12 +444,12 @@ def main():
     if Resource.FILES in resources_to_replicate:
         print("Replicating files...")
         cognite.replicator.files.replicate(
-            src_client,
-            dst_client,
-            src_dst_dataset_mapping,
-            config,
-            config.get("batch_size"),
-            config.get("number_of_threads"),
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+            num_threads=config.get("number_of_threads"),
+            config=config,
+            src_dst_dataset_mapping=src_dst_dataset_mapping,
             delete_replicated_if_not_in_src=delete_replicated_if_not_in_src,
             delete_not_replicated_in_dst=delete_not_replicated_in_dst,
             target_external_ids=config.get("files_external_ids"),
@@ -454,7 +458,11 @@ def main():
 
     if Resource.RAW in resources_to_replicate:
         print("Replicating raw...")
-        cognite.replicator.raw.replicate(src_client, dst_client, config.get("batch_size"))
+        cognite.replicator.raw.replicate(
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+        )
 
     if Resource.DATAPOINTS in resources_to_replicate:
         print("Replicating datapoints...")
@@ -469,6 +477,42 @@ def main():
             value_manipulation_lambda_fnc=config.get("value_manipulation_lambda_fnc"),
         )
 
+    if Resource.SEQUENCES in resources_to_replicate:
+        print("Replicating sequences...")
+        cognite.replicator.sequences.replicate(
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+            num_threads=config.get("number_of_threads"),
+            config=config,
+            src_dst_dataset_mapping=src_dst_dataset_mapping,
+            delete_replicated_if_not_in_src=delete_replicated_if_not_in_src,
+            delete_not_replicated_in_dst=delete_not_replicated_in_dst,
+            target_external_ids=config.get("sequences_external_ids"),
+            exclude_pattern=config.get("events_exclude_pattern"),
+        )
+        print("Replicating sequences rows...")
+        cognite.replicator.sequence_rows.replicate(
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+            num_threads=config.get("number_of_threads"),
+        )
+
+    if Resource.RELATIONSHIPS in resources_to_replicate:
+        print("Replicating relationships...")
+        cognite.replicator.relationships.replicate(
+            client_src=src_client,
+            client_dst=dst_client,
+            batch_size=config.get("batch_size"),
+            num_threads=config.get("number_of_threads"),
+            config=config,
+            src_dst_dataset_mapping=src_dst_dataset_mapping,
+            delete_replicated_if_not_in_src=delete_replicated_if_not_in_src,
+            delete_not_replicated_in_dst=delete_not_replicated_in_dst,
+            target_external_ids=config.get("relationships_external_ids"),
+        )
+
 
 if __name__ == "__main__":
     start = time.time()
