@@ -51,7 +51,7 @@ def create_time_series(
         security_categories=src_ts.security_categories,
         legacy_name=src_ts.external_id,
         data_set_id=datasets.replicate(src_client, dst_client, src_ts.data_set_id, src_dst_dataset_mapping)
-        if config.get("dataset_support", False)
+        if config and config.get("dataset_support", False)
         else None,
     )
 
@@ -98,7 +98,7 @@ def update_time_series(
     dst_ts.security_categories = src_ts.security_categories
     dst_ts.data_set_id = (
         datasets.replicate(src_client, dst_client, src_ts.data_set_id, src_dst_dataset_mapping)
-        if config.get("dataset_support", False)
+        if config and config.get("dataset_support", False)
         else None
     )
     return dst_ts
@@ -210,10 +210,10 @@ def copy_ts(
 def replicate(
     client_src: CogniteClient,
     client_dst: CogniteClient,
-    src_dst_dataset_mapping: Dict[int, int],
-    config: Dict,
     batch_size: int = 10000,
     num_threads: int = 1,
+    config: Dict = None,
+    src_dst_dataset_mapping: Dict[int, int] = {},
     delete_replicated_if_not_in_src: bool = False,
     delete_not_replicated_in_dst: bool = False,
     skip_unlinkable: bool = False,
@@ -228,11 +228,10 @@ def replicate(
     Args:
         client_src: The client corresponding to the source project.
         client_dst: The client corresponding to the destination project.
-        src_dst_dataset_mapping: dictionary mapping the source dataset ids to the destination ones
-                config: dict corresponding to the selected yaml config file
-
         batch_size: The biggest batch size to post chunks in.
         num_threads: The number of threads to be used.
+        config: dict corresponding to the selected yaml config file
+        src_dst_dataset_mapping: dictionary mapping the source dataset ids to the destination ones
         delete_replicated_if_not_in_src: If True, will delete replicated assets that are in the destination,
         but no longer in the source project (Default=False).
         delete_not_replicated_in_dst: If True, will delete assets from the destination if they were not replicated
@@ -335,15 +334,17 @@ def replicate(
 
     if delete_replicated_if_not_in_src:
         ids_to_delete = replication.find_objects_to_delete_if_not_in_src(ts_src, ts_dst)
-        client_dst.time_series.delete(id=ids_to_delete)
-        logging.info(
-            f"Deleted {len(ids_to_delete)} time series destination ({project_dst})"
-            f" because they were no longer in source ({project_src})   "
-        )
+        if ids_to_delete:
+            client_dst.time_series.delete(id=ids_to_delete)
+            logging.info(
+                f"Deleted {len(ids_to_delete)} time series destination ({project_dst})"
+                f" because they were no longer in source ({project_src})   "
+            )
     if delete_not_replicated_in_dst:
         ids_to_delete = replication.find_objects_to_delete_not_replicated_in_dst(ts_dst)
-        client_dst.time_series.delete(id=ids_to_delete)
-        logging.info(
-            f"Deleted {len(ids_to_delete)} time series in destination ({project_dst}) because"
-            f"they were not replicated from source ({project_src})   "
-        )
+        if ids_to_delete:
+            client_dst.time_series.delete(id=ids_to_delete)
+            logging.info(
+                f"Deleted {len(ids_to_delete)} time series in destination ({project_dst}) because"
+                f"they were not replicated from source ({project_src})   "
+            )
